==> procciao-0.12.tar.gz: procciao-0.12/setup.py <==
from setuptools import setup, find_packages
import codecs
import os
# 
here = os.path.abspath(os.path.dirname(__file__))
# 
with open(os.path.join(os.path.abspath(os.path.dirname(__file__)),'README.md'), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()\

from pathlib import Path
this_directory = Path(__file__).parent
#long_description = (this_directory / "README.md").read_text()

VERSION = '''0.12'''
DESCRIPTION = '''A library for killing processes/subprocesses the most gracefully way possible'''

# Setting up
setup(
    name="procciao",
    version=VERSION,
    license='MIT',
    url = 'https://github.com/hansalemaos/procciao',
    author="Johannes Fischer",
    author_email="aulasparticularesdealemaosp@gmail.com",
    description=DESCRIPTION,
long_description = long_description,
long_description_content_type="text/markdown",
    #packages=['consolectrlchandler', 'exceptdrucker', 'flatten_any_dict_iterable_or_whatsoever', 'flatten_everything', 'getfilenuitkapython', 'pidconnectioninfos', 'touchtouch', 'wmicprocsdict'],
    keywords=['killing', 'pid'],
    classifiers=['Development Status :: 4 - Beta', 'Programming Language :: Python :: 3 :: Only', 'Programming Language :: Python :: 3.10', 'Topic :: Software Development :: Libraries :: Python Modules', 'Topic :: Utilities'],
    install_requires=['consolectrlchandler', 'exceptdrucker', 'flatten_any_dict_iterable_or_whatsoever', 'flatten_everything', 'getfilenuitkapython', 'pidconnectioninfos', 'touchtouch', 'wmicprocsdict'],
    include_package_data=True
)
#python setup.py sdist bdist_wheel
#twine upload dist/*

==> procciao-0.13.tar.gz: procciao-0.13/setup.py <==
from setuptools import setup, find_packages
import codecs
import os
# 
here = os.path.abspath(os.path.dirname(__file__))
# 
with open(os.path.join(os.path.abspath(os.path.dirname(__file__)),'README.md'), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()\

from pathlib import Path
this_directory = Path(__file__).parent
#long_description = (this_directory / "README.md").read_text()

VERSION = '''0.13'''
DESCRIPTION = '''A library for killing processes/subprocesses the most gracefully way possible'''

# Setting up
setup(
    name="procciao",
    version=VERSION,
    license='MIT',
    url = 'https://github.com/hansalemaos/procciao',
    author="Johannes Fischer",
    author_email="aulasparticularesdealemaosp@gmail.com",
    description=DESCRIPTION,
long_description = long_description,
long_description_content_type="text/markdown",
    #packages=['consolectrlchandler', 'flatten_any_dict_iterable_or_whatsoever', 'flatten_everything', 'pidconnectioninfos', 'touchtouch', 'wmicprocsdict'],
    keywords=['killing', 'pid'],
    classifiers=['Development Status :: 4 - Beta', 'Programming Language :: Python :: 3 :: Only', 'Programming Language :: Python :: 3.10', 'Topic :: Software Development :: Libraries :: Python Modules', 'Topic :: Utilities'],
    install_requires=['consolectrlchandler', 'flatten_any_dict_iterable_or_whatsoever', 'flatten_everything', 'pidconnectioninfos', 'touchtouch', 'wmicprocsdict'],
    include_package_data=True
)
#python setup.py sdist bdist_wheel
#twine upload dist/*
